# pylint: disable-all

try:
    import aiohttp
except ImportError:
    raise RuntimeError("aiohttp is not installed, possibly running in python27?")
from logging import getLogger

logger = getLogger("trustpilot.async_client")

from os import environ
import base64
from trustpilot import auth, utils


class TrustpilotAsyncSession:
    __SUPPORTED_HTTP_METHODS = ["post", "get", "put", "delete"]

    def __init__(self, *args, **kwargs):
        self.setup(**kwargs)
        self.headers = {}

    def setup(
        self,
        api_host=None,
        api_version=None,
        api_key=None,
        api_secret=None,
        username=None,
        password=None,
        access_token=None,
        token_issuer_path=None,
        token_issuer_host=None,
        user_agent=None,
        **kwargs
    ):

        self.api_version = api_version or environ.get("TRUSTPILOT_API_VERSION", "v1")
        self.api_host = api_host or environ.get(
            "TRUSTPILOT_API_HOST", "https://api.trustpilot.com"
        )
        self.token_issuer_host = token_issuer_host or self.api_host
        self.access_token = access_token
        self.token_issuer_path = token_issuer_path or environ.get(
            "TRUSTPILOT_API_TOKEN_ISSUER_PATH",
            "oauth/oauth-business-users-for-applications/accesstoken",
        )
        self.hooks = dict()
        self.user_agent = user_agent or environ.get(
            "TRUSTPILOT_USER_AGENT", auth.get_user_agent()
        )

        if not self.api_host.startswith("http"):
            raise aiohttp.http_exceptions.InvalidURLError(
                "'{}' is not a valid api_host url".format(api_host)
            )

        try:
            self.api_key = api_key or environ["TRUSTPILOT_API_KEY"]
            self.api_secret = api_secret or environ.get("TRUSTPILOT_API_SECRET", "")
            self.username = username or environ.get("TRUSTPILOT_USERNAME")
            self.password = password or environ.get("TRUSTPILOT_PASSWORD")
            self.access_token = access_token
        except KeyError as e:
            logger.debug("Not auth setup, missing env-var or setup for {}".format(e))

        return self

    async def get_request_auth_headers(self):
        url, data, headers = auth.create_access_token_request_params(self)
        async with aiohttp.ClientSession() as session:
            async with session.post(url, data=data, headers=headers) as response:
                response_json = await response.json()
                self.access_token = response_json["access_token"]
                self.headers.update(
                    {
                        "Authorization": "Bearer {}".format(self.access_token),
                        "apikey": self.api_key,
                        "User-Agent": self.user_agent,
                    }
                )

    async def authenticated_request(self, method, url, **kwargs):
        if method not in self.__SUPPORTED_HTTP_METHODS:
            raise RuntimeError("Http method {} not supported".format(method))

        cleaned_url = utils.get_cleaned_url(url, self.api_host, self.api_version)

        async with aiohttp.ClientSession(headers=self.headers) as session:
            http_method = getattr(session, method)
            response = await http_method(cleaned_url, **kwargs)

        if response.status == 401:
            await self.get_request_auth_headers()
            async with aiohttp.ClientSession(headers=self.headers) as session:
                http_method = getattr(session, method)
                response = await http_method(cleaned_url, **kwargs)
        return response

    async def post(self, url, *args, **kwargs):
        return await self.authenticated_request("post", url, *args, **kwargs)

    async def get(self, url, *args, **kwargs):

        return await self.authenticated_request("get", url, *args, **kwargs)

    async def put(self, url, *args, **kwargs):
        return await self.authenticated_request("put", url, *args, **kwargs)

    async def delete(self, url, *args, **kwargs):
        return await self.authenticated_request("delete", url, *args, **kwargs)


default_session = TrustpilotAsyncSession()
get = default_session.get
post = default_session.post
put = default_session.put
delete = default_session.delete



# -*- coding: utf-8 -*-
import requests
import logging

from trustpilot import auth, utils
from os import environ
from warnings import warn

logger = logging.getLogger(__name__)
_session_cache = {}


def disable_ssl_warnings():
    try:
        import requests.packages.urllib3

        urllib3_logger = logging.getLogger("requests")
        urllib3_logger.setLevel(logging.WARNING)
        urllib3_logger.propagate = False
        requests.packages.urllib3.disable_warnings()
        logger.info(
            {
                "message": "Ssl warnings from urllib3 disabled! "
                "(info: http://urllib3.readthedocs.io/en/latest/advanced-usage.html#ssl-warnings)"
            }
        )
    except ImportError:
        logger.error("Error importing urllib3 when disabling its logging")


class TrustpilotSession(requests.Session):
    def __init__(self, **kwargs):
        super(TrustpilotSession, self).__init__()
        self.setup(**kwargs)
        self._pre_hooks = []
        self._post_hooks = []
        self.auth = self._pre_request_callback

    def setup(
        self,
        api_host=None,
        api_version=None,
        api_key=None,
        api_secret=None,
        username=None,
        password=None,
        access_token=None,
        token_issuer_path=None,
        token_issuer_host=None,
        user_agent=None,
        **kwargs
    ):

        self.api_version = api_version or environ.get("TRUSTPILOT_API_VERSION", "v1")
        self.api_host = api_host or environ.get(
            "TRUSTPILOT_API_HOST", "https://api.trustpilot.com"
        )
        self.token_issuer_host = token_issuer_host or self.api_host
        self.access_token = access_token
        self.token_issuer_path = token_issuer_path or environ.get(
            "TRUSTPILOT_API_TOKEN_ISSUER_PATH",
            "oauth/oauth-business-users-for-applications/accesstoken",
        )
        self.hooks = dict()
        self.user_agent = user_agent or environ.get(
            "TRUSTPILOT_USER_AGENT", auth.get_user_agent()
        )

        if not self.api_host.startswith("http"):
            raise requests.URLRequired(
                "'{}' is not a valid api_host url".format(api_host)
            )

        try:
            self.api_key = api_key or environ["TRUSTPILOT_API_KEY"]
            self.api_secret = api_secret or environ.get("TRUSTPILOT_API_SECRET", "")
            self.username = username or environ.get("TRUSTPILOT_USERNAME")
            self.password = password or environ.get("TRUSTPILOT_PASSWORD")
            self.access_token = access_token
            self.hooks["response"] = self._post_request_callback
        except KeyError as e:
            logger.debug("Not auth setup, missing env-var or setup for {}".format(e))

        return self

    def get_request_auth_headers(self):
        url, data, headers = auth.create_access_token_request_params(self)
        response = requests.post(url=url, headers=headers, data=data)

        self.access_token = None
        if response and response.status_code == requests.codes["ok"]:
            response_json = response.json()
            self.access_token = response_json["access_token"]

        self.headers.update(
            {
                "Authorization": "Bearer {}".format(self.access_token),
                "apikey": self.api_key,
                "User-Agent": self.user_agent,
            }
        )
        return self.headers

    def _pre_request_callback(self, request):
        for hook in self._pre_hooks:
            hook(self, request)
        return request

    def _post_request_callback(self, response, *args, **kwargs):
        req = response.request
        retry = getattr(req, "authentication_retry", True)

        if retry and response.status_code == requests.codes.unauthorized:
            logger.debug(
                {"message": "reauthenticating and retrying once", "url": req.url}
            )
            req.authentication_retry = False
            req.headers.update(self.get_request_auth_headers())
            response = self.send(req)
        else:
            for hook in self._post_hooks:
                hook(self, response)

        return response

    def register_pre_hook(self, hook):
        self._pre_hooks.append(hook)

    def register_post_hook(self, hook):
        self._post_hooks.append(hook)

    def request(self, method, url, **kwargs):  # pylint: disable=W0221
        cleaned_url = utils.get_cleaned_url(url, self.api_host, self.api_version)

        return super(TrustpilotSession, self).request(method, cleaned_url, **kwargs)


def get_session():
    warn(
        "'trustpilot.client.get_session' is deprecated!, "
        "use trustpilot.client.default_session instead",
        DeprecationWarning,
    )
    return default_session


def create_session(
    api_host=None,
    api_version=None,
    api_key=None,
    api_secret=None,
    username=None,
    password=None,
    access_token_path=None,
    token_issuer_host=None,
    access_token=None,
    user_agent=None,
):
    warn(
        "'trustpilot.client.create_session' is deprecated!, "
        "use trustpilot.client.default_session.setup instead",
        DeprecationWarning,
    )

    default_session.setup(
        api_host=api_host,
        api_version=api_version,
        api_key=api_key,
        api_secret=api_secret,
        access_token=access_token,
        token_issuer_path=access_token_path,
        token_issuer_host=token_issuer_host,
        username=username,
        password=password,
        user_agent=user_agent,
    )

    return default_session


def post(url, data=None, json=None, **kwargs):
    return default_session.post(url, data=data, json=json, **kwargs)


def head(url, **kwargs):
    return default_session.head(url, **kwargs)


def options(url, **kwargs):
    return default_session.options(url, **kwargs)


def get(url, **kwargs):
    return default_session.get(url, **kwargs)


def patch(url, data=None, **kwargs):
    return default_session.patch(url, data=data, **kwargs)


def delete(url, **kwargs):
    return default_session.delete(url, **kwargs)


def put(url, data=None, **kwargs):
    return default_session.put(url, data, **kwargs)


default_session = TrustpilotSession()



# -*- coding: utf-8 -*-
import click
import json
import logging
import sys
import os.path as path
from inspect import getsourcefile


current_dir = path.dirname(path.abspath(getsourcefile(lambda: 0)))
sys.path.insert(0, current_dir[: current_dir.rfind(path.sep)])
logger = logging.getLogger(__name__)

from trustpilot import client, auth, __version__
from collections import OrderedDict


@click.pass_context
def get_verbosity(ctx):
    return ctx.meta.get("trustpilot.verbosity", 0)


def format_response(response):
    content = response.text
    try:
        content = response.json()
    except ValueError:
        pass
    output = OrderedDict()
    output["url"] = response.url
    output["status"] = response.status_code
    if get_verbosity():  # pylint: disable=E1120
        headers = response.headers
        output["headers"] = OrderedDict((k, headers[k]) for k in headers)
    output["content"] = content

    return json.dumps(output, indent=2)


@click.group(invoke_without_command=True)
@click.pass_context
@click.option("--host", type=str, help="host name", envvar="TRUSTPILOT_API_HOST")
@click.option(
    "--version", type=str, help="api version (e.g. v1)", envvar="TRUSTPILOT_API_VERSION"
)
@click.option("--key", type=str, help="api key", envvar="TRUSTPILOT_API_KEY")
@click.option("--secret", type=str, help="api secret", envvar="TRUSTPILOT_API_SECRET")
@click.option(
    "--token_issuer_host",
    type=str,
    default="",
    help="token issuer host name",
    envvar="TRUSTPILOT_API_TOKEN_ISSUER_HOST",
)
@click.option(
    "--username",
    type=str,
    default="",
    help="Trustpilot username",
    envvar="TRUSTPILOT_USERNAME",
)
@click.option(
    "--password",
    type=str,
    default="",
    help="Trustpilot password",
    envvar="TRUSTPILOT_PASSWORD",
)
@click.option("-c", type=str, help="json config file name")
@click.option("-v", "--verbose", count=True, help="verbosity level")
def cli(ctx, **kwargs):
    splash = r"""
         _____              _         _ _       _
        |_   _|            | |       (_) |     | |
          | |_ __ _   _ ___| |_ _ __  _| | ___ | |_
          | | '__| | | / __| __| '_ \| | |/ _ \| __|
          | | |  | |_| \__ \ |_| |_) | | | (_) | |_
          \_/_|   \__,_|___/\__| .__/|_|_|\___/ \__|
                               | |
                               |_|
          ___        _   _____ _ _            _
         / _ \      (_) /  __ \ (_)          | |
        / /_\ \_ __  _  | /  \/ |_  ___ _ __ | |_
        |  _  | '_ \| | | |   | | |/ _ \ '_ \| __|
        | | | | |_) | | | \__/\ | |  __/ | | | |_
        \_| |_/ .__/|_|  \____/_|_|\___|_| |_|\__|
              | |
              |_|   """
    splash = (
        click.style(splash, fg="green")
        + click.style("v{}".format(__version__), fg="red")
        + "\n"
    )

    values_dict = {}
    config_filename = kwargs.pop("c")

    if config_filename:
        with open(config_filename, "r") as f:
            values_dict = json.load(f)

    # setup verbosity level for global access
    verbosity = kwargs.get("verbose")
    ctx.meta["trustpilot.verbosity"] = verbosity

    # setup logging (increasing information levels)
    # _ : content, url, status_code
    # v : headers
    # vv: logging.INFO level
    # vvv: logging.DEBUG level
    levels = {2: logging.INFO, 3: logging.DEBUG}
    logging_level = levels.get(verbosity, logging.CRITICAL)

    logger.setLevel(logging_level)
    if logging_level > logging.DEBUG:
        # disable urllib3 logging
        client.disable_ssl_warnings()

    if ctx.invoked_subcommand is None:
        click.echo("\n".join([splash, ctx.get_help()]))
        return

    # create default session
    try:
        client.create_session(
            api_host=kwargs.pop("host")
            or values_dict.get("TRUSTPILOT_API_HOST")
            or "https://api.tp-staging.com",
            api_version=kwargs.pop("version")
            or values_dict.get("TRUSTPILOT_API_VERSION")
            or "v1",
            api_key=kwargs.pop("key") or values_dict["TRUSTPILOT_API_KEY"],
            api_secret=(
                kwargs.pop("secret") or values_dict.get("TRUSTPILOT_API_SECRET", None)
            ),
            token_issuer_host=(
                kwargs.pop("token_issuer_host")
                or values_dict.get("TRUSTPILOT_API_TOKEN_ISSUER_HOST", None)
            ),
            username=kwargs.pop("username") or values_dict["TRUSTPILOT_USERNAME"],
            password=kwargs.pop("password") or values_dict["TRUSTPILOT_PASSWORD"],
        )
    except KeyError as key:
        raise SystemExit("Missing argument: {}".format(key))


cli_command = cli.command(
    context_settings=dict(ignore_unknown_options=True, allow_extra_args=True)
)


@cli_command
def create_access_token():
    """
    Get an access token
    """
    client.default_session.get_request_auth_headers()
    click.echo(client.default_session.access_token)


@cli_command
@click.argument("path")
def get(path):
    """
    Send a GET request
    """
    response = client.get(url=path)
    click.echo(format_response(response))


@cli_command
@click.argument("path")
@click.option("--data", type=str, help="json_data to post")
@click.option(
    "--content-type",
    type=str,
    default="application/json",
    help="content-type, default=application/json",
)
def post(path, data, content_type):
    """
    Send a POST request with specified data
    """
    headers = {"content-type": content_type}
    response = client.post(url=path, data=data, headers=headers)
    click.echo(format_response(response))


@cli_command
@click.argument("path")
def delete(path):
    """
    Send a DELETE request
    """
    response = client.delete(url=path)
    click.echo(format_response(response))


@cli_command
@click.argument("path")
@click.option("--data", type=str, help="json_data to post")
@click.option(
    "--content-type",
    type=str,
    default="application/json",
    help="content-type, default=application/json",
)
def put(path, data, content_type):
    """
    Send a PUT request with specified data
    """
    headers = {"content-type": content_type}
    response = client.put(url=path, data=data, headers=headers)
    click.echo(format_response(response))


if __name__ == "__main__":
    cli()  # pylint: disable=E1120



def get_cleaned_url(url, api_host, api_version):
    if any(prefix in url for prefix in ["http://", "https://"]):
        return url

    cleaned_url = api_host.rstrip("/")
    if url.startswith("/{}".format(api_version)):
        cleaned_url += url
    else:
        cleaned_url += "/{}{}".format(api_version, url)

    return cleaned_url



try:
    from unittest import mock
except ImportError:
    import mock
import unittest
import responses
import json

from trustpilot import client


def assert_not_called(mock):
    assert mock.call_count == 0


def assert_called_once(mock):
    assert mock.call_count == 1


class TestCliMethods(unittest.TestCase):
    def setUp(self):
        self.api_host = "https://hostname.com"
        self.api_key = "secret_api_key"
        self.api_secret = "secret_api_secret"
        self.token_issuer_path = (
            "oauth/oauth-business-users-for-applications/accesstoken"
        )
        self.token_issuer_host = "https://hostname.com"
        self.username = "username"
        self.password = "password"
        self.api_version = "v1"

        self.request_url = "/this/1"

        self.exp_headers = {
            "apikey": "secret_api_key",
            "Authorization": "Bearer access_token",
        }

    @property
    def session(self):
        session = client.default_session.setup(
            api_host=self.api_host,
            api_key=self.api_key,
            api_secret=self.api_secret,
            token_issuer_path=self.token_issuer_path,
            token_issuer_host=self.token_issuer_host,
            username=self.username,
            password=self.password,
            api_version=self.api_version,
        )
        return session

    @mock.patch("trustpilot.client.auth", autospec=True)
    def test_deprecated_create_session(self, auth_mock):
        session = client.create_session(
            api_host=self.api_host,
            api_key=self.api_key,
            api_secret=self.api_secret,
            access_token_path=self.token_issuer_path,
            token_issuer_host=self.token_issuer_host,
            username=self.username,
            password=self.password,
            api_version=self.api_version,
        )
        for attr in [
            "api_key",
            "api_secret",
            "api_host",
            "token_issuer_path",
            "token_issuer_host",
            "username",
            "password",
            "api_version",
        ]:
            assert getattr(self, attr) == getattr(session, attr)

    @responses.activate
    def test_get_public_endpoint_with_apikey_and_no_access_token(self):
        with responses.RequestsMock(assert_all_requests_are_fired=True) as rsps:
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="bar", status=200
            )

            session = client.default_session.setup(api_host=self.api_host)
            response = session.get(self.request_url)
            assert response.text == "bar"
            assert response.status_code == 200

    @responses.activate
    def test_request_renew_auth_token_success(self):
        with responses.RequestsMock(assert_all_requests_are_fired=True) as rsps:
            rsps.add(
                responses.POST,
                "https://hostname.com/v1/oauth/oauth-business-users-for-applications/accesstoken",
                body='{"access_token":"access_token"}',
                status=200,
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="foo", status=401
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="bar", status=200
            )

            session = self.session
            response = session.get(self.request_url)

            headers = dict(response.request.headers)

            assert response.text == "bar"
            assert all(value == headers[key] for key, value in self.exp_headers.items())

    @responses.activate
    def test_request_renew_auth_token_fail(self):
        with responses.RequestsMock(assert_all_requests_are_fired=True) as rsps:
            rsps.add(
                responses.POST,
                "https://hostname.com/v1/oauth/oauth-business-users-for-applications/accesstoken",
                body="go away",
                status=401,
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="bar", status=401
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="foo", status=401
            )

            session = self.session
            response = session.get(self.request_url)

            assert response.text == "foo"

    @responses.activate
    def test_no_hooks(self):
        with responses.RequestsMock(assert_all_requests_are_fired=True) as rsps:
            rsps.add(
                responses.POST,
                "https://hostname.com/v1/oauth/oauth-business-users-for-applications/accesstoken",
                body='{"access_token":"access_token"}',
                status=200,
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="foo", status=401
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="bar", status=200
            )
            session = self.session
            hook_mock = mock.Mock()

            # no hooks
            session.get(self.request_url)
            assert_not_called(hook_mock.pre_hook)
            assert_not_called(hook_mock.post_hook)

    @responses.activate
    def test_pre_hook(self):
        with responses.RequestsMock(assert_all_requests_are_fired=True) as rsps:
            rsps.add(
                responses.POST,
                "https://hostname.com/v1/oauth/oauth-business-users-for-applications/accesstoken",
                body='{"access_token":"access_token"}',
                status=200,
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="foo", status=401
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="bar", status=200
            )
            session = self.session
            hook_mock = mock.Mock()

            session.register_pre_hook(hook_mock.pre_hook)

            session.get(self.request_url)

            assert_called_once(hook_mock.pre_hook)
            assert_not_called(hook_mock.post_hook)

    @responses.activate
    def test_post_hook(self):
        with responses.RequestsMock(assert_all_requests_are_fired=True) as rsps:
            rsps.add(
                responses.POST,
                "https://hostname.com/v1/oauth/oauth-business-users-for-applications/accesstoken",
                body='{"access_token":"access_token"}',
                status=200,
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="foo", status=401
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="bar", status=200
            )
            session = self.session
            hook_mock = mock.Mock()

            session.register_post_hook(hook_mock.post_hook)
            session.get(self.request_url)
            assert_not_called(hook_mock.pre_hook)
            assert_called_once(hook_mock.post_hook)

    @responses.activate
    def test_pre_and_post_hooks(self):
        with responses.RequestsMock(assert_all_requests_are_fired=True) as rsps:
            rsps.add(
                responses.POST,
                "https://hostname.com/v1/oauth/oauth-business-users-for-applications/accesstoken",
                body='{"access_token":"access_token"}',
                status=200,
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="foo", status=401
            )
            rsps.add(
                responses.GET, "https://hostname.com/v1/this/1", body="bar", status=200
            )
            session = self.session
            hook_mock = mock.Mock()

            session.register_pre_hook(hook_mock.pre_hook)
            session.register_post_hook(hook_mock.post_hook)

            session.get(self.request_url)

            assert_called_once(hook_mock.pre_hook)
            assert_called_once(hook_mock.post_hook)

    @responses.activate
    def test_api_version(self):
        with responses.RequestsMock(assert_all_requests_are_fired=True) as rsps:
            rsps.add(responses.GET, "https://hostname.com/v1/foo/bar", status=200)
            rsps.add(responses.GET, "https://hostname.com/v1/v2/foo/bar", status=404)
            rsps.add(responses.GET, "https://12345.com/v23/foo/bar", status=200)
            
            session = self.session
            res = session.get("/v1/foo/bar")
            double_res = session.get("/v2/foo/bar")
            full_url_res = session.get("https://12345.com/v23/foo/bar")

            assert res.status_code == 200
            assert double_res.status_code == 404
            assert full_url_res.status_code == 200



import requests
import base64
import logging
import platform
from trustpilot import __version__ as VERSION


OS = platform.system()
PYTHON_VERSION = platform.python_version()
SCOPE = "external"


def get_user_agent():
    user_agent = "python-trustpilot-client?scope={scope}&version={version}&python-version={python_version}&os={os}".format(
        scope=SCOPE, version=VERSION, python_version=PYTHON_VERSION, os=OS
    )
    return user_agent


def create_access_token_request_params(session):
    url = "{token_issuer_host}/{api_version}/{token_issuer_path}".format(
        token_issuer_host=session.token_issuer_host.rstrip("/"),
        api_version=session.api_version.rstrip("/"),
        token_issuer_path=session.token_issuer_path,
    )
    data = {
        "grant_type": "password",
        "username": session.username,
        "password": session.password,
    }

    headers = {
        "Authorization": "Basic {}".format(
            base64.b64encode(
                (session.api_key + ":" + session.api_secret).encode("ascii")
            ).decode("ascii")
        ),
        "User-Agent": session.user_agent,
    }

    return url, data, headers



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup
import sys
import os

readme = open("README.md", "r").read()

history = open("HISTORY.md").read()

requirements = [
    "Click==6.7", 
    "requests>=2.22.0",
]

test_requirements = [
    "responses==0.6",
    "mock",
    "pytest==3.2.0",
    "pytest-readme==1.0.0",
] + requirements

if sys.version_info >= (3, 5):
    test_requirements.append("aioresponses==0.6.1")

async_requirements = ["aiohttp==3.6.2"] + requirements

extras = {"test": test_requirements, "async": async_requirements}
# get version
metadata = {}
version_filename = os.path.join(os.path.dirname(__file__), "trustpilot", "__init__.py")
exec(open(version_filename).read(), None, metadata)

setup(
    name="trustpilot",
    version=metadata["__version__"],
    description="trustpilot api client including cli tool",
    long_description=readme + "\n\n" + history,
    long_description_content_type="text/markdown",
    author=metadata["__author__"],
    author_email=metadata["__email__"],
    url="https://github.com/trustpilot/python-trustpilot",
    packages=["trustpilot"],
    package_dir={"trustpilot": "trustpilot"},
    entry_points={"console_scripts": ["trustpilot_api_client=trustpilot.cli:cli"]},
    include_package_data=True,
    install_requires=requirements,
    zip_safe=False,
    keywords="trustpilot api client",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
    ],
    test_suite="tests",
    tests_require=test_requirements,
    extras_require=extras,
)



# pylint: disable-all
import pytest
import sys
from aioresponses import aioresponses
import asyncio
from trustpilot import async_client

@pytest.mark.skipif(
    sys.version_info < (3, 5, 2), reason="requires python 3.5.2 or above"
)
def test_async_client_auth_and_get():
    loop = asyncio.get_event_loop()

    with aioresponses() as m:
        m.get("https://api.tp-staging.com/v1/foo/bar", status=401)
        m.post(
            "https://api.tp-staging.com/v1/oauth/oauth-business-users-for-applications/accesstoken",
            payload=dict(access_token="foobarbaz"),
        )
        m.get("https://api.tp-staging.com/v1/foo/bar", payload=dict(foo="foobarbaz"))

        session = async_client.TrustpilotAsyncSession(
            api_host="https://api.tp-staging.com",
            api_key="something",
            api_secret="secret",
            username="username",
            password="password",
            api_version="v1",
        )

        async def get_response():
            response = await session.get("/foo/bar")
            response_json = await response.json()
            assert response_json["foo"] == "foobarbaz"
            assert session.access_token == "foobarbaz"

        resp = loop.run_until_complete(get_response())


@pytest.mark.skipif(
    sys.version_info < (3, 5, 2), reason="requires python 3.5.2 or above"
)
def test_async_api_version():
    loop = asyncio.get_event_loop()

    with aioresponses() as m:
        m.get("https://api.tp-staging.com/v1/foo/bar", status=200)
        m.get("https://api.tp-staging.com/v1/v2/foo/bar", status=404)
        m.get("https://12345.com/v23/foo/bar", status=200)

        session = async_client.TrustpilotAsyncSession(
            api_host="https://api.tp-staging.com",
            api_key="something",
            api_secret="secret",
            username="username",
            password="password",
            api_version="v1",
        )

        async def get_response():
            res = await session.get("/v1/foo/bar")
            double_res = await session.get("/v2/foo/bar")
            full_url_res = await session.get("https://12345.com/v23/foo/bar")

            assert res.status == 200
            assert double_res.status == 404
            assert full_url_res.status == 200

        resp = loop.run_until_complete(get_response())